<?php 
	/*=======================================================================
	 * copyright (c) AL-Design Works 
	 * http://cms.al-design.jp/
	 * このソースファイルは CMS Designer の一部です。
	 * 詳しいライセンス規約についてはウェブサイトを参照してください。
	 *=======================================================================
	 */

	require_once( "include/cmsdconfig.php.inc" );
	require_once( "include/manager.php.inc" );
	require_once( "include/login.php.inc" );
	require_once( "include/user.php.inc" );
	
	$editor = null;

	cmsd_session_start();
	
	mb_language( 'Japanese' );
	mb_internal_encoding( gCMSDInternalEncoding() );	
	
	// --- OutputConfigの読み込み ---------------------------------------------------------
	loadSiteConfig();
	
	// ログアウト要求があった場合、ログアウトの前に該当ユーザーのエントリ編集ロックを全て解除する。
	if ( isset( $_GET['logout'] ) )
	{
		if ( LoginManager::IsAuthed() )
		{
			$user = LoginManager::GetAuthedUser();
			EditingEntryLock::ReleaseLocksByUser( $user->getUserId() );
		}
	}
	
	// ログインオブジェクトを生成
	$loginForm = new LoginForm();
	
	// ユーザー認証
	$isAuth = $loginForm->authUser();
	
	header("Content-Type:text/html;charset=UTF-8");
	
	// 認証済みか？
	if ( $isAuth )
	{
		// 認証済みなら、各画面の処理に入る。		
		
		// アクション履歴をセッションよりロード
		if ( isset( $_SESSION['actionStack'] ) )
		{
			$actionStack = $_SESSION['actionStack'];
		}
		else
		{
			$actionStack = array();
		}
		
		// 画面遷移前処理
		$actionName = getGETParam( 'p' );	//	$_GET['p']
		///$action =& createAction( $actionName );
		$action = createAction( $actionName );
		
		if ( ! isset($action) )
		{
			// アクション名が省略されているので、同一画面内遷移か、初回アクセス。
			if ( count($actionStack) > 0 )
			{
				// 遷移履歴が残っているなら、同一画面内遷移。
				$action =& $actionStack[ count($actionStack)-1 ];
			}
			else
			{
				// 遷移履歴が残っていないなら、初回アクセス。
				///$action =& createAction( 'entrynames' );	// トップページを生成
				$action = createAction( 'entrynames' );	// トップページを生成
				array_push( $actionStack, $action );
			}
		}
		else
		{
			// 履歴をクリアして履歴の先頭に遷移先画面を設定する。
			$actionStack = array(); // 履歴をクリア
			array_push( $actionStack, $action );
		}
		
		// エントリ編集画面以外の画面に移ったら、該当ユーザーのエントリロックを解除する。
		$actionClassName = get_class( $action );
		if ( strtolower( $actionClassName ) != 'entryeditor' )
		{
			$user = LoginManager::GetAuthedUser();
			EditingEntryLock::ReleaseLocksByUser( $user->getUserId() );
		}

		// アクションに処理を委譲する。
		$nextActionName = $action->procRequest();
		// procRequestでactionオブジェクトの中身が変更された可能性があるので、actionStackの先頭を再度設定しなおす。
		array_pop( $actionStack );
		array_push( $actionStack, $action );
		
		// 次画面がある場合は、次画面を表示する。
		switch ( $nextActionName )
		{
			// １つ上の階層へ戻る
			case 'pop' :
				$action =& array_pop( $actionStack );
				$action->procRequest();
				// procRequestでオブジェクトの中身が変更された可能性があるので、スタックの先頭を再度設定しなおす。。
				array_pop( $actionStack );
				array_push( $actionStack, $action );
				break;
				
			// ユーザー一覧編集へ戻る
			case 'edituserlist' :
				// 一覧画面を表示する。
				$action = new EditUserListForm();
				$action->procRequest();
				$actionStack = array();
				array_push( $actionStack, $action );	// このへんはやっつけコード。あとで全体と合わせて調整が必要。→現状これでOK
				break;
				
			default :
				break;
		}
		
		// 遷移履歴をセッションに格納する。
		$_SESSION['actionStack'] = $actionStack;
		
	}
	else
	{
		// 再ログインの為に、過去のセッションを消す。
		unset( $_SESSION['actionStack'] );
		
		// 認証されていないなら、ログインフォームを表示する。
		$loginForm->dispForm();
	}
	
	
	
	function createAction( $actionName )
	{
		
		// パラメータによって処理を分岐させる。pパラメータに画面名を付けて
		// 呼び出された場合、その画面オブジェクトを生成する。
		// 画面オブジェクトはセッションに入れて保持する。
 	   	switch ( $actionName )
		{
			case 'versioninfo' :
				$action = new VersionInfoAction();
				break;
			
			// ユーザー一覧編集
			case 'edituserlist' :
				$action = new EditUserListForm();
				break;
			
			case 'edituser' :
				$userId = $_GET['userid'];
				$action = new EditUserForm( $userId );
				break;
				
			// エントリ一覧
			case 'entries' :
				$entryName = $_GET['entryname'];
				$action = new EntriesForEditor( $entryName );
				break;
					
			// エントリ
			case 'entry' :
				$entryName = $_GET['entryname'];
				$entryID = $_GET['entryid'];
				$action = new EntryEditor( $entryName, $entryID );
				break;
		
			// エントリ名一覧、又はデフォルト
			case 'entrynames' :
		   		$action = new EntryNamesForEditor();
				break;
			
			default :
				/*
				// editorセッション変数が空なら、エントリ名一覧画面を表示する。
				if ( ! isset( $_SESSION["editor"] ) )
				{
					$_SESSION["editor"] = new EntryNamesForEditor();
				}
				*/				
				$action = null;
				break;
		}
		
		return $action;
	}
	
	// siteConfigをロードし、各種設定を読み込む。
	function loadSiteConfig()
	{
		$siteConfig = new CMSSiteConfig();
		$outputConfig =& $siteConfig->getOutputConfig();	// インスタンスを変更する為、参照で取得する。
		
		// XSLTライブラリ番号の設定
		ADXslt::setXsltLibNo( $outputConfig->getXsltLibNo() );
		
		// XSLTによる文字エンコーディング処理の抑制の有無
		ADXslt::setDisableXsltEncoding( $outputConfig->getDisableXsltEncoding() );
		
		//print "ADXslt::setXsltLibNo( " . $outputConfig->getXsltLibNo() . " )<br />";
		//print "ADXslt::setDisableXsltEncoding( " .  ( $outputConfig->getDisableXsltEncoding() ? "True" : "False" ) . " )<br />";
	}
	
?>